# cheapodb

A very opinionated, very basic implementation of AWS Glue targeting Athena and S3.  

This is probably only useful to us. We wanted a dirt cheap way to persist scraped, raw data with
querying ability.